@@ -19,9 +19,11 @@ use Mojo::Loader;
 use Mojo::UserAgent;
 use base qw( Test::Builder::Module );
 use Carp qw( croak );
+use File::Basename ();
+use File::Path ();
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -529,6 +531,35 @@ sub create_ua
   shift->_add_ua;
 }
 
+
+sub extract_data_section
+{
+  my($self, $regex) = @_;
+
+  $regex //= qr{};
+  my $caller = caller;
+  my $all = Mojo::Loader::data_section $caller;
+  my $home = File::HomeDir->my_home;
+  my $tb = __PACKAGE__->builder;
+
+  foreach my $name (keys %$all)
+  {
+    use autodie;
+    next unless $name =~ $regex;
+    my $basename = File::Basename::basename $name;
+    my $dir      = File::Basename::dirname  $name;
+
+    $tb->note("[extract] DIR  $home/dir");
+    File::Path::mkpath "$home/$dir", 0, 0700;
+    $tb->note("[extract] FILE $home/$dir/$basename");
+    open my $fh, '>', "$home/$dir/$basename";
+    print $fh $all->{$name};
+    close $fh;
+  }
+  
+  $self;
+}
+
 1;
 
 __END__
@@ -543,7 +574,7 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -854,6 +885,13 @@ Passes if the given service is not stopped.
 Create a new instance of Mojo::UserAgent which can be used
 to connect to nodes in the test cluster.
 
+=head2 extract_data_section
+
+ $cluster->extract_data_section($regex);
+
+Extract the files from the data section of the current package
+that match the given regex.
+
 =head1 CAVEATS
 
 Some combination of Mojolicious, FreeBSD, IPv6 and TLS/SSL
